@@ -170,6 +170,10 @@ headers_normal["ref_voltage_txt"] = "reference_voltage"  # new
 headers_normal["dv_dt_txt"] = "dv_dt"
 headers_normal["frequency_txt"] = "frequency"  # new
 headers_normal["amplitude_txt"] = "amplitude"  # new
+headers_normal["channel_id_txt"] = "channel_id"  # new Arbin SQL Server
+headers_normal["data_flag_txt"] = "data_flag"  # new Arbin SQL Server
+headers_normal["test_name_txt"] = "test_name"  # new Arbin SQL Server
+headers_normal["test_id_txt"] = "test_id"  # new Arbin SQL Server
 
 # - summary -
 
@@ -180,7 +184,9 @@ headers_summary["test_time"] = headers_normal["test_time_txt"]
 headers_summary["datetime"] = headers_normal["datetime_txt"]
 headers_summary["discharge_capacity_raw"] = headers_normal["discharge_capacity_txt"]
 headers_summary["charge_capacity_raw"] = headers_normal["charge_capacity_txt"]
-
+headers_summary["test_name"] = headers_normal["test_name_txt"]
+headers_summary["data_flag"] = headers_normal["data_flag_txt"]
+headers_summary["channel_id"] = headers_normal["channel_id_txt"]
 headers_summary["discharge_capacity"] = "discharge_capacity_u_mAh_g"
 headers_summary["charge_capacity"] = "charge_capacity_u_mAh_g"
 headers_summary["cumulated_charge_capacity"] = "cumulated_charge_capacity_u_mAh_g"
@@ -258,7 +264,9 @@ headers_step_table["rate_avr"] = "rate_avr"
 
 # 01.05.2020: added fix column names and renamed to singular form.
 # 08.07.2020: added nominal capacity, experiment type and comment.
+# 10.08.2021: added id_key (can be used for look-up in other dbs).
 headers_journal["filename"] = "filename"
+headers_journal["id_key"] = "id_key"
 headers_journal["mass"] = "mass"
 headers_journal["total_mass"] = "total_mass"
 headers_journal["loading"] = "loading"
@@ -267,6 +275,7 @@ headers_journal["experiment"] = "experiment"
 headers_journal["fixed"] = "fixed"
 headers_journal["label"] = "label"
 headers_journal["cell_type"] = "cell_type"
+headers_journal["instrument"] = "instrument"
 headers_journal["raw_file_names"] = "raw_file_names"
 headers_journal["cellpy_file_name"] = "cellpy_file_name"
 headers_journal["group"] = "group"
