@@ -197,15 +197,33 @@ class Cell(object):
                     value = self.__getattribute__(p)
                     txt += f"<b>{p}</b>: {value}<br>"
         txt += "</p>"
+        try:
+            raw_txt = f"<p><b>raw data-frame (summary)</b><br>{self.raw.describe()._repr_html_()}</p>"
+            raw_txt += f"<p><b>raw data-frame (head)</b><br>{self.raw.head()._repr_html_()}</p>"
+        except AttributeError:
+            raw_txt = "<p><b>raw data-frame </b><br> not found!</p>"
+        except ValueError:
+            raw_txt = "<p><b>raw data-frame </b><br> does not contain any columns!</p>"
 
-        raw_txt = f"<p><b>raw data-frame (summary)</b><br>{self.raw.describe()._repr_html_()}</p>"
-        raw_txt += (
-            f"<p><b>raw data-frame (head)</b><br>{self.raw.head()._repr_html_()}</p>"
-        )
-        summary_txt = f"<p><b>summary data-frame (summary)</b><br>{self.summary.describe()._repr_html_()}</p>"
-        summary_txt += f"<p><b>summary data-frame (head)</b><br>{self.summary.head()._repr_html_()}</p>"
-        steps_txt = f"<p><b>steps data-frame (summary)</b><br>{self.steps.describe()._repr_html_()}</p>"
-        steps_txt += f"<p><b>steps data-frame (head)</b><br>{self.steps.head()._repr_html_()}</p>"
+        try:
+            summary_txt = f"<p><b>summary data-frame (summary)</b><br>{self.summary.describe()._repr_html_()}</p>"
+            summary_txt += f"<p><b>summary data-frame (head)</b><br>{self.summary.head()._repr_html_()}</p>"
+        except AttributeError:
+            summary_txt = "<p><b>summary data-frame </b><br> not found!</p>"
+        except ValueError:
+            summary_txt = (
+                "<p><b>summary data-frame </b><br> does not contain any columns!</p>"
+            )
+
+        try:
+            steps_txt = f"<p><b>steps data-frame (summary)</b><br>{self.steps.describe()._repr_html_()}</p>"
+            steps_txt += f"<p><b>steps data-frame (head)</b><br>{self.steps.head()._repr_html_()}</p>"
+        except AttributeError:
+            steps_txt = "<p><b>steps data-frame </b><br> not found!</p>"
+        except ValueError:
+            steps_txt = (
+                "<p><b>steps data-frame </b><br> does not contain any columns!</p>"
+            )
 
         return obj + txt + summary_txt + steps_txt + raw_txt
 
@@ -553,8 +571,9 @@ def collect_capacity_curves(
 
         except NullData as e:
             logging.warning(e)
-            break
-
+            d = pd.DataFrame()
+            d.name = cycle
+            charge_list.append(d)
         else:
             d = pd.DataFrame({"q": q, "v": v})
             # d.name = f"{cycle}"
@@ -590,7 +609,7 @@ def interpolate_y_on_x(
             dx: step-value (defaults to 10.0)
             number_of_points: number of points for interpolated values (use
                 instead of dx and overrides dx if given).
-            direction (-1,1): if direction is negetive, then invert the
+            direction (-1,1): if direction is negative, then invert the
                 x-values before interpolating.
             **kwargs: arguments passed to scipy.interpolate.interp1d
 
@@ -599,6 +618,9 @@ def interpolate_y_on_x(
 
         """
 
+    # TODO: allow for giving a fixed interpolation range (x-values).
+    #  Remember to treat extrapolation properly (e.g. replace with NaN?).
+
     if x is None:
         x = df.columns[0]
     if y is None:
