@@ -40,7 +40,6 @@ def _make_average(
     cell_id = ""
     not_a_number = np.NaN
     new_frames = []
-
     if columns is None:
         columns = frames[0].columns
 
@@ -50,7 +49,7 @@ def _make_average(
                 set(
                     [
                         "_".join(
-                            k.split("_")[key_index_bounds[0] : key_index_bounds[1]]
+                            k.split("_")[key_index_bounds[0]: key_index_bounds[1]]
                         )
                         for k in keys
                     ]
@@ -297,11 +296,88 @@ def add_areal_capacity(cell, cell_id, journal):
 
 def _remove_outliers_from_summary(s, filter_vals, freeze_indexes=None):
     if freeze_indexes is not None:
-        filter_vals[freeze_indexes] = True
+        try:
+            filter_vals[freeze_indexes] = True
+        except IndexError:
+            logging.critical(
+                f"Could not freeze - missing cycle indexes {freeze_indexes}"
+            )
 
     return s[filter_vals]
 
 
+def remove_outliers_from_summary_on_window(
+    s, window_size=3, cut=0.1, iterations=1, col_name=None, freeze_indexes=None
+):
+    """Removes outliers based based on neighbours"""
+    if col_name is None:
+        col = hdr_summary["charge_capacity"]
+
+    else:
+        col = hdr_summary[col_name]
+
+    def fractional_std(x):
+        return np.std(x) / np.mean(x)
+
+    for j in range(iterations):
+        fractional_deviation_series = (
+            s[col]
+                .rolling(window=window_size, center=True, min_periods=1)
+                .apply(fractional_std)
+        )
+        filter_vals = fractional_deviation_series < cut
+        s = s[filter_vals]
+
+    s = _remove_outliers_from_summary(s, filter_vals, freeze_indexes=freeze_indexes)
+
+    return s
+
+
+def remove_outliers_from_summary_on_nn_distance(
+    s, distance=0.7, filter_cols=None, freeze_indexes=None
+):
+    """Remove outliers with missing neighbours.
+
+    Args:
+        s (pandas.DataFrame): summary frame
+        distance (float): cut-off (all cycles that have a closest neighbour further apart this number will be removed)
+        filter_cols (list): list of column headers to perform the filtering on (defaults to charge and discharge capacity)
+        freeze_indexes (list): list of cycle indexes that should never be removed (defaults to cycle 1)
+
+    Returns:
+        filtered summary (pandas.DataFrame)
+
+    Returns:
+
+    """
+    if filter_cols is None:
+        filter_cols = [
+            hdr_summary["charge_capacity"],
+            hdr_summary["discharge_capacity"],
+        ]
+
+    def neighbour_window(y):
+        y = y.values
+        if len(y) == 1:
+            # only included in case the pandas rolling function changes in the future
+            return 0.5
+        if len(y) == 2:
+            return abs(np.diff(y)) / np.mean(y)
+        else:
+            return min(abs(y[1] - y[0]), abs(y[1] - y[2])) / min(
+                np.mean(y[0:1]), np.mean(y[1:])
+            )
+
+    s2 = s[filter_cols].copy()
+
+    r = s2[filter_cols].rolling(3, center=True, min_periods=1).apply(neighbour_window)
+    filter_vals = (r < distance).all(axis=1)
+
+    s = _remove_outliers_from_summary(s, filter_vals, freeze_indexes=freeze_indexes)
+
+    return s
+
+
 def remove_outliers_from_summary_on_zscore(
     s, zscore_limit=4, filter_cols=None, freeze_indexes=None
 ):
@@ -407,7 +483,7 @@ def remove_first_cycles_from_summary(s, first=None):
     return s
 
 
-def yank_after(b, last=None, keep_old=True):
+def yank_after(b, last=None, keep_old=False):
     """Cut all cycles after a given cycle index number.
 
     Args:
@@ -435,10 +511,11 @@ def yank_after(b, last=None, keep_old=True):
             last_this_cell = last
         s = remove_last_cycles_from_summary(s, last_this_cell)
         c.cell.summary = s
-    return b
+    if keep_old:
+        return b
 
 
-def yank_before(b, first=None, keep_old=True):
+def yank_before(b, first=None, keep_old=False):
     """Cut all cycles before a given cycle index number.
 
     Args:
@@ -466,7 +543,8 @@ def yank_before(b, first=None, keep_old=True):
             first_this_cell = first
         s = remove_first_cycles_from_summary(s, first_this_cell)
         c.cell.summary = s
-    return b
+    if keep_old:
+        return b
 
 
 def yank_outliers(
@@ -480,6 +558,9 @@ def yank_outliers(
     remove_last=False,
     iterations=1,
     zscore_multiplyer=1.3,
+    distance=None,
+    window_size=None,
+    window_cut=0.1,
     keep_old=False,
 ):
     """Remove outliers from a batch object.
@@ -496,21 +577,29 @@ def yank_outliers(
         iterations (int): repeat z-score filtering if `zscore_limit` is given.
         zscore_multiplyer (int): multiply `zscore_limit` with this number between each z-score filtering
             (should usually be less than 1).
+        distance (float): nearest neighbour normalised distance required (typically 0.5).
+        window_size (int): number of cycles to include in the window.
+        window_cut (float): cut-off.
+
         keep_old (bool): perform filtering of a copy of the batch object
             (not recommended at the moment since it then loads the full cellpyfile).
 
     Returns:
-        cellpy.utils.batch object (returns a copy if `keep_old` is True).
+        if keep_old: new cellpy.utils.batch object.
+        else: dictionary of removed cycles
     """
 
     if keep_old:
         b = deepcopy(b)
 
+    removed_cycles = dict()
+
     # remove based on indexes and values
     for cell_number, cell_label in enumerate(b.experiment.cell_names):
         logging.debug(f"yanking {cell_label} ")
         c = b.experiment.data[cell_label]
         s = c.cell.summary
+        before = set(s.index)
         if remove_indexes is not None:
             logging.debug("removing indexes")
             if isinstance(remove_indexes, dict):
@@ -526,6 +615,7 @@ def yank_outliers(
             s = remove_outliers_from_summary_on_index(
                 s, remove_indexes_this_cell, remove_last_this_cell
             )
+
         s = remove_outliers_from_summary_on_value(
             s,
             low=low,
@@ -533,10 +623,32 @@ def yank_outliers(
             filter_cols=filter_cols,
             freeze_indexes=freeze_indexes,
         )
-        c.cell.summary = s
 
-    # removed based on zscore
+        if distance is not None:
+            s = remove_outliers_from_summary_on_nn_distance(
+                s,
+                distance=distance,
+                filter_cols=filter_cols,
+                freeze_indexes=freeze_indexes,
+            )
+            c.cell.summary = s
+
+        if window_size is not None:
+            s = remove_outliers_from_summary_on_window(
+                s,
+                window_size=window_size,
+                cut=window_cut,
+                iterations=iterations,
+                freeze_indexes=freeze_indexes,
+            )
+
+        removed = before - set(s.index)
+        c.cell.summary = s
+        if removed:
+            removed_cycles[cell_label] = list(removed)
+
     if zscore_limit is not None:
+        logging.info("using the zscore - removed cycles not kept track on")
         for j in range(iterations):
             tot_rows_removed = 0
             for cell_number, cell_label in enumerate(b.experiment.cell_names):
@@ -548,19 +660,24 @@ def yank_outliers(
                     zscore_limit=zscore_limit,
                     freeze_indexes=freeze_indexes,
                 )
-
+                # TODO: populate removed_cycles
                 rows_removed = n1 - len(s)
                 tot_rows_removed += rows_removed
                 c.cell.summary = s
             if tot_rows_removed == 0:
                 break
             zscore_limit *= zscore_multiplyer
-    return b
+
+    if keep_old:
+        return b
+    else:
+        return removed_cycles
 
 
 # from helpers - updated
 def concatenate_summaries(
     b,
+    max_cycle=None,
     rate=None,
     on="charge",
     columns=None,
@@ -575,6 +692,7 @@ def concatenate_summaries(
     rate_column=None,
     inverse=False,
     inverted=False,
+    key_index_bounds=[1, -2],
 ):
 
     """Merge all summaries in a batch into a gigantic summary data frame.
@@ -584,6 +702,7 @@ def concatenate_summaries(
 
     Args:
         b (cellpy.batch object): the batch with the cells.
+        max_cycle (int): drop all cycles above this value.
         rate (float): filter on rate (C-rate)
         on (str or list of str): only select cycles if based on the rate of this step-type (e.g. on="charge").
         columns (list): selected column(s) (using cellpy name) [defaults to "charge_capacity"]
@@ -598,6 +717,8 @@ def concatenate_summaries(
         rate_column (str): name of the column containing the C-rates.
         inverse (bool): select steps that does not have the given C-rate.
         inverted (bool): select cycles that does not have the steps filtered by given C-rate.
+        key_index_bounds (list): used when creating a common label for the cells by splitting and combining from
+            key_index_bound[0] to key_index_bound[1].
 
     Returns:
         Multi-index pandas.DataFrame
@@ -665,6 +786,8 @@ def concatenate_summaries(
             c = b.experiment.data[cell_id]
 
             if not c.empty:
+                if max_cycle is not None:
+                    c = c.drop_from(max_cycle + 1)
                 if add_areal:
                     c = add_areal_capacity(c, cell_id, b.experiment.journal)
 
@@ -721,13 +844,19 @@ def concatenate_summaries(
             try:
                 if normalize_cycles:
                     s, cell_id = _make_average(
-                        frames_sub, keys_sub, normalize_cycles_headers + columns, True
+                        frames_sub,
+                        keys_sub,
+                        normalize_cycles_headers + columns,
+                        True,
+                        key_index_bounds,
                     )
                     s = add_normalized_cycle_index(s, nom_cap=_nom_cap)
                     if hdr_cum_charge not in columns:
                         s = s.drop(columns=hdr_cum_charge)
                 else:
-                    s, cell_id = _make_average(frames_sub, keys_sub, columns)
+                    s, cell_id = _make_average(
+                        frames_sub, keys_sub, columns, key_index_bounds=key_index_bounds
+                    )
             except ValueError as e:
                 print("could not make average!")
                 print(e)
@@ -745,8 +874,11 @@ def concatenate_summaries(
             used_names = []
             new_keys = []
             for name in keys:
-                if name in used_names:
-                    name += "x"
+                while True:
+                    if name in used_names:
+                        name += "x"
+                    else:
+                        break
                 new_keys.append(name)
                 used_names.append(name)
             keys = new_keys
