@@ -24,12 +24,19 @@ from cellpy.readers.core import collect_capacity_curves
 # TODO: @jepe - binning method (assigned to Asbjoern)
 
 
-class Converter(object):
+class Converter:
     """Class for dq-dv handling.
 
     Typical usage is to  (1) set the data,  (2) inspect the data,
     (3) pre-process the data,
     (4) perform the dq-dv transform, and finally (5) post-process the data.
+
+    A short note about normalization:
+    If normalization is set to False, then no normalization will be done.
+    If normalization is True, and normalization_factor is None, the total capacity of the half cycle will be
+       used for normalization, else the normalization_factor will be used.
+    If normalization is True, and normalization_roof is not None, the capacity divided by normalization_roof will be
+       used for normalization.
     """
 
     def __init__(
@@ -230,7 +237,7 @@ class Converter(object):
         if self.max_points is not None:
             len_capacity = min(self.max_points, self.len_capacity)
         elif self.capacity_resolution is not None:
-            len_capacity = round(abs(c2 - c1) / self.capacity_resolution, 0)
+            len_capacity = int(round(abs(c2 - c1) / self.capacity_resolution, 0))
         else:
             len_capacity = self.len_capacity
 
@@ -614,18 +621,17 @@ def dqdv(
         max_points: restricting to max points in vector (capacity-selected)
 
     Returns: voltage, dqdv
-
-    Notes:
-        PEC data (Helge)
-            pre_smoothing = False
-            diff_smoothing = False
-            pos_smoothing = False
-            voltage_resolution = 0.005
-        PEC data (Preben)
-            ...
-        Arbin data (IFE)
-            ...
     """
+    # Notes:
+    #     PEC data
+    #         pre_smoothing = False
+    #         diff_smoothing = False
+    #         pos_smoothing = False
+    #         voltage_resolution = 0.005
+    #     PEC data
+    #         ...
+    #     Arbin data (IFE)
+    #         ...
 
     converter = Converter(**kwargs)
     logging.debug("dqdv - starting")
@@ -772,27 +778,31 @@ def _constrained_dq_dv_using_dataframes(capacity, minimum_v, maximum_v, **kwargs
 
 def _make_ica_charge_curves(cycles_dfs, cycle_numbers, minimum_v, maximum_v, **kwargs):
     incremental_charge_list = []
+
     for c, n in zip(cycles_dfs, cycle_numbers):
-        if not c.empty:
+        if c.empty:
+            logging.info(f"{n} is empty")
+            v = [np.nan]
+            dq = [np.nan]
+        else:
             v, dq = _constrained_dq_dv_using_dataframes(
                 c, minimum_v, maximum_v, **kwargs
             )
-            if not incremental_charge_list:
-                d = pd.DataFrame({"v": v})
-                d.name = "voltage"
-                incremental_charge_list.append(d)
+        if not incremental_charge_list:
+            d = pd.DataFrame({"v": v})
+            d.name = "voltage"
+            incremental_charge_list.append(d)
 
-                d = pd.DataFrame({f"dq": dq})
-                d.name = n
-                incremental_charge_list.append(d)
+            d = pd.DataFrame({f"dq": dq})
+            d.name = n
+            incremental_charge_list.append(d)
 
-            else:
-                d = pd.DataFrame({f"dq": dq})
-                # d.name = f"{cycle}"
-                d.name = n
-                incremental_charge_list.append(d)
         else:
-            print(f"{n} is empty")
+            d = pd.DataFrame({f"dq": dq})
+            # d.name = f"{cycle}"
+            d.name = n
+            incremental_charge_list.append(d)
+
     return incremental_charge_list
 
 
@@ -870,12 +880,14 @@ def _dqdv_split_frames(
         max_cycle_number=max_cycle_number,
         cycle=cycle,
     )
+    logging.debug(f"retrieved {len(charge_dfs)} charge cycles")
     # charge_df = pd.concat(
     # charge_dfs, axis=1, keys=[k.name for k in charge_dfs])
 
     ica_charge_dfs = _make_ica_charge_curves(
         charge_dfs, cycles, minimum_v, maximum_v, **kwargs
     )
+
     ica_charge_df = pd.concat(
         ica_charge_dfs, axis=1, keys=[k.name for k in ica_charge_dfs]
     )
@@ -889,6 +901,7 @@ def _dqdv_split_frames(
         max_cycle_number=max_cycle_number,
         cycle=cycle,
     )
+    logging.debug(f"retrieved {len(dcharge_dfs)} discharge cycles")
     ica_dcharge_dfs = _make_ica_charge_curves(
         dcharge_dfs, cycles, minimum_v, maximum_v, **kwargs
     )
@@ -909,14 +922,14 @@ def _dqdv_split_frames(
     return ica_charge_df, ica_discharge_df
 
 
-def check_class_ica():
+def _check_class_ica():
     print(40 * "=")
     print("running check_class_ica")
     print(40 * "-")
 
     import matplotlib.pyplot as plt
 
-    cell = get_a_cell_to_play_with()
+    cell = _get_a_cell_to_play_with()
     cycle = 5
     print("looking at cycle %i" % cycle)
 
@@ -977,7 +990,7 @@ def check_class_ica():
     plt.show()
 
 
-def get_a_cell_to_play_with():
+def _get_a_cell_to_play_with():
     from cellpy import cellreader
 
     # -------- defining overall path-names etc ----------
@@ -1007,6 +1020,6 @@ if __name__ == "__main__":
     import pandas as pd
     from cellpy import cellreader
 
-    cell = get_a_cell_to_play_with()
+    cell = _get_a_cell_to_play_with()
 
     a = dqdv_frames(cell)
