@@ -4,6 +4,7 @@ import shutil
 import datetime
 import pytest
 import logging
+import pathlib
 
 import cellpy.readers.core
 from cellpy.exceptions import DeprecatedFeature
@@ -18,20 +19,26 @@ log.setup_logging(default_level="DEBUG")
 @pytest.fixture
 def cellpy_data_instance():
     from cellpy import cellreader
+    from cellpy import log
+    log.setup_logging(default_level="INFO")
 
     return cellreader.CellpyData()
 
 
-# TODO: fix this: dont save a file that is used in other test modules
 @pytest.fixture(scope="module")
 def dataset():
     from cellpy import cellreader
+    from cellpy import log
+    log.setup_logging(default_level="INFO")
+    p = pathlib.Path(fdv.cellpy_file_path)
 
-    a = cellreader.CellpyData()
-    a.from_raw(fdv.res_file_path)
-    a.set_mass(1.0)
-    a.make_summary(find_ocv=False, find_ir=True, find_end_voltage=True)
-    a.save(fdv.cellpy_file_path)
+    if not p.is_file():
+        logging.info(f"pytest fixture could not find {fdv.cellpy_file_path} - making it from raw and saving")
+        a = cellreader.CellpyData()
+        a.from_raw(fdv.res_file_path)
+        a.set_mass(1.0)
+        a.make_summary(find_ocv=False, find_ir=True, find_end_voltage=True)
+        a.save(fdv.cellpy_file_path)
 
     b = cellreader.CellpyData()
     b.load(fdv.cellpy_file_path)
@@ -39,15 +46,16 @@ def dataset():
 
 
 # TODO: fix this: not smart to save cellpyfile that will be used by other modules
-def test_create_cellpyfile(cellpy_data_instance):
+def test_create_cellpyfile(cellpy_data_instance, tmp_path):
     # create a cellpy file from the res-file (used for testing)
     cellpy_data_instance.from_raw(fdv.res_file_path)
     cellpy_data_instance.set_mass(1.0)
     cellpy_data_instance.make_summary(
         find_ocv=False, find_ir=True, find_end_voltage=True
     )
-    print(f"trying to save the cellpy file to {fdv.cellpy_file_path}")
-    cellpy_data_instance.save(fdv.cellpy_file_path)
+    name = pathlib.Path(tmp_path) / pathlib.Path(fdv.cellpy_file_path).name
+    logging.info(f"trying to save the cellpy file to {name}")
+    cellpy_data_instance.save(name)
 
 
 @pytest.mark.parametrize(
@@ -352,7 +360,9 @@ def test_search_for_files():
     run_files, cellpy_file = filefinder.search_for_files(
         fdv.run_name, raw_file_dir=fdv.raw_data_dir, cellpy_file_dir=fdv.output_dir
     )
-
+    print(f"fdv.res_file_path: {fdv.res_file_path}")
+    print(f"run_files: {run_files}")
+    print(run_files)
     assert fdv.res_file_path in run_files
     assert os.path.basename(cellpy_file) == fdv.cellpy_file_name
 
@@ -458,15 +468,15 @@ def test_load_step_specs(cellpy_data_instance):
 
 def test_load_arbin_res_aux_single(cellpy_data_instance):
     cellpy_data_instance.loadcell(fdv.res_file_path4)
-    assert 'aux_0_u_C' in cellpy_data_instance.cell.raw.columns
-    assert 'aux_d_0_dt_u_dC_dt' in cellpy_data_instance.cell.raw.columns
+    assert "aux_0_u_C" in cellpy_data_instance.cell.raw.columns
+    assert "aux_d_0_dt_u_dC_dt" in cellpy_data_instance.cell.raw.columns
     assert cellpy_data_instance.cell.raw.size == 195345
 
 
 def test_load_arbin_res_aux_multiple(cellpy_data_instance):
     cellpy_data_instance.loadcell(fdv.res_file_path3)
-    assert 'aux_0_u_V' in cellpy_data_instance.cell.raw.columns
-    assert 'aux_11_u_V' in cellpy_data_instance.cell.raw.columns
+    assert "aux_0_u_V" in cellpy_data_instance.cell.raw.columns
+    assert "aux_11_u_V" in cellpy_data_instance.cell.raw.columns
     assert cellpy_data_instance.cell.raw.size == 134976
 
 
@@ -635,6 +645,18 @@ def test_save_cellpyfile_auto_extension(cellpy_data_instance):
     assert not os.path.isfile(tmp_file + ".h5")
 
 
+def test_save_cellpyfile_auto_extension_pathlib(cellpy_data_instance):
+    cellpy_data_instance.loadcell(fdv.res_file_path)
+    cellpy_data_instance.make_summary(find_ir=True)
+    cellpy_data_instance.make_step_table()
+    tmp_file = pathlib.Path(next(tempfile._get_candidate_names()))
+    cellpy_data_instance.save(tmp_file)
+    tmp_file = tmp_file.with_suffix(".h5")
+    assert tmp_file.is_file()
+    os.remove(tmp_file)
+    assert not tmp_file.is_file()
+
+
 def test_save_cvs(cellpy_data_instance):
     cellpy_data_instance.loadcell(fdv.res_file_path)
     cellpy_data_instance.make_summary(find_ir=True)
@@ -658,20 +680,21 @@ def test_check_cellpy_file(cellpy_data_instance):
     ids = cellpy_data_instance._check_cellpy_file(file_name)
 
 
-def test_cellpyfile_roundtrip():
+def test_cellpyfile_roundtrip(tmp_path):
     from cellpy import cellreader
 
+    cellpy_file_name = pathlib.Path(tmp_path) / pathlib.Path(fdv.cellpy_file_path).name
     cdi = cellreader.CellpyData()
 
     # create a cellpy file from the res-file
     cdi.from_raw(fdv.res_file_path)
     cdi.set_mass(1.0)
     cdi.make_summary(find_ocv=False, find_ir=True, find_end_voltage=True)
-    cdi.save(fdv.cellpy_file_path)
+    cdi.save(cellpy_file_name)
 
     # load the cellpy file
     cdi = cellreader.CellpyData()
-    cdi.load(fdv.cellpy_file_path)
+    cdi.load(cellpy_file_name)
     cdi.make_step_table()
     cdi.make_summary(find_ocv=False, find_ir=True, find_end_voltage=True)
 
