@@ -99,7 +99,10 @@ def test_ica_index_bounds(dataset):
 
 def test_ica_dqdv_cycles(dataset):
     cycles = dataset.get_cap(
-        method="forth-and-forth", categorical_column=True, label_cycle_number=True, insert_nan=False,
+        method="forth-and-forth",
+        categorical_column=True,
+        label_cycle_number=True,
+        insert_nan=False,
     )
     dQdV = ica.dqdv_cycles(cycles)
 
@@ -156,7 +159,7 @@ def test_dqdv_frames_split(dataset):
     assert df_ica_charge.size == 300
     assert df_ica_discharge.size == 300
     df_ica_charge, df_ica_discharge = ica.dqdv_frames(dataset, split=True)
-    assert df_ica_charge.size == 5100
+    assert df_ica_charge.size == 5400
     assert df_ica_discharge.size == 5400
     assert "voltage" in df_ica_charge.columns
     assert "cycle" in df_ica_charge.columns
